import { createViteLoader } from "../core/module-loader/index.js";
import { createDevelopmentEnvironment } from "../core/render/dev/index.js";
import { createRouteManifest } from "../core/routing/index.js";
import { baseMiddleware } from "./base.js";
import { createController } from "./controller.js";
import { handleRequest } from "./request.js";
function createVitePluginAstroServer({
  settings,
  logging,
  fs: fsMod
}) {
  return {
    name: "astro:server",
    configureServer(viteServer) {
      const loader = createViteLoader(viteServer);
      let env = createDevelopmentEnvironment(settings, logging, loader);
      let manifest = createRouteManifest({ settings, fsMod }, logging);
      const serverController = createController({ loader });
      function rebuildManifest(needsManifestRebuild, _file) {
        env.routeCache.clearAll();
        if (needsManifestRebuild) {
          manifest = createRouteManifest({ settings }, logging);
        }
      }
      viteServer.watcher.on("add", rebuildManifest.bind(null, true));
      viteServer.watcher.on("unlink", rebuildManifest.bind(null, true));
      viteServer.watcher.on("change", rebuildManifest.bind(null, false));
      return () => {
        if (settings.config.base !== "/") {
          viteServer.middlewares.stack.unshift({
            route: "",
            handle: baseMiddleware(settings, logging)
          });
        }
        viteServer.middlewares.use(async (req, res) => {
          if (req.url === void 0 || !req.method) {
            res.writeHead(500, "Incomplete request");
            res.end();
            return;
          }
          handleRequest(env, manifest, serverController, req, res);
        });
      };
    },
    transform(code, id, opts = {}) {
      if (opts.ssr)
        return;
      if (!id.includes("vite/dist/client/client.mjs"))
        return;
      return code.replace(
        "this.text('.message-body', message.trim());",
        `const urlPattern = /(\\b(https?|ftp):\\/\\/[-A-Z0-9+&@#\\/%?=~_|!:,.;]*[-A-Z0-9+&@#\\/%=~_|])/gim;
						function escapeHtml(unsafe){return unsafe.replace(/</g, "&lt;").replace(/>/g, "&gt;");}
 					const escapedMessage = escapeHtml(message);
					this.root.querySelector(".message-body").innerHTML = escapedMessage.trim().replace(urlPattern, '<a href="$1" target="_blank">$1</a>');`
      ).replace("</style>", ".message-body a {\n  color: #ededed;\n}\n</style>").replace(/\.tip \{[^}]*\}/gm, ".tip {\n  display: none;\n}").replace(/\[vite\]/g, "[astro]");
    }
  };
}
export {
  createVitePluginAstroServer as default
};
